cgexplore.systems\_optimisation.ChromosomeGenerator
===================================================

.. currentmodule:: cgexplore.systems_optimisation

.. autoclass:: ChromosomeGenerator
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~ChromosomeGenerator.add_forcefield_dict
      ~ChromosomeGenerator.add_gene
      ~ChromosomeGenerator.crossover_population
      ~ChromosomeGenerator.dedupe_population
      ~ChromosomeGenerator.define_chromosomes
      ~ChromosomeGenerator.get_num_chromosomes
      ~ChromosomeGenerator.get_prec_ids
      ~ChromosomeGenerator.get_term_ids
      ~ChromosomeGenerator.get_topo_ids
      ~ChromosomeGenerator.get_va_ids
      ~ChromosomeGenerator.mutate_population
      ~ChromosomeGenerator.select_chromosome
      ~ChromosomeGenerator.select_random_population
      ~ChromosomeGenerator.select_similar_chromosome
      ~ChromosomeGenerator.yield_chromosomes
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ChromosomeGenerator.present_beads
      ~ChromosomeGenerator.vdw_bond_cutoff
      ~ChromosomeGenerator.prefix
      ~ChromosomeGenerator.chromosome_map
      ~ChromosomeGenerator.chromosome_types
      ~ChromosomeGenerator.chromosomed_terms
      ~ChromosomeGenerator.definer_dict
   
   